# -*- coding: utf-8 -*-
import logging

from odoo import SUPERUSER_ID, api, models
from odoo.exceptions import AccessError
from odoo.tools.translate import _


class IrConfigParameter(models.Model):
    _inherit = "ir.config_parameter"

    # The DB UUID should never be deleted or modified in the Odoo database only. This will cause
    # inconsistencies since the DB UUID is also stored in the meta database. If the UUID needs
    # to be changed, it must be done in the customer and the meta databases.
    # An exception is set for the SUPERUSER_ID for compatibility reason. `set_param` is called
    # programmatically in `reinitialize`, which is critical in the various SaaS flows (free
    # trials, duplicates...).

    @api.multi
    def write(self, vals):
        if self.env.user.id != SUPERUSER_ID:
            for icp in self:
                if icp.key == "database.uuid":
                    raise AccessError(
                        _(
                            "UUID synchronization error.\n"
                            "Please contact our support at https://www.odoo.com/help"
                        )
                    )
        return super(IrConfigParameter, self).write(vals)

    @api.multi
    def unlink(self):
        if self.env.user.id != SUPERUSER_ID:
            for icp in self:
                if icp.key == "database.uuid":
                    raise AccessError(
                        _(
                            "UUID synchronization error.\n"
                            "Please contact our support at https://www.odoo.com/help"
                        )
                    )
        return super(IrConfigParameter, self).unlink()
